OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veldu skrá.",
    "File is too big" : "Skrá er of stór",
    "Invalid file provided" : "Ógild skrá gefin",
    "No image or file provided" : "Engin mynd eða skrá gefin",
    "Unknown filetype" : "Óþekkt skráartegund",
    "Invalid image" : "Ógild mynd",
    "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
    "No temporary profile picture available, try again" : "Engin bráðabirgða einkennismynd er tiltæk, reyndu aftur",
    "No crop data provided" : "Enginn gögn um utanskurð gefin",
    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
    "Crop is not square" : "Utanskurður er ekki ferningslaga",
    "Couldn't reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
    "Couldn't reset password because the token is expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
    "Couldn't send reset email. Please make sure your username is correct." : "Gat ekki sent endurstillingu í tölvupósti. Gakktu úr skugga um að notandanafn þitt sé rétt.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti því það er ekkert gilt tölvupóstfang fyrir þennan notanda. Hafðu samband við kerfisstjóra.",
    "%s password reset" : "%s lykilorð endurstillt",
    "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
    "Error loading tags" : "Villa við að hlaða inn merkjum",
    "Tag already exists" : "Merki er þegar til",
    "Error deleting tag(s)" : "Villa við að eyða merki/merkjum",
    "Error tagging" : "Villa við að merkja",
    "Error untagging" : "Villa við afmerkja",
    "Error favoriting" : "Villa við bókmerkingu ",
    "Error unfavoriting" : "Villa við afmá bókmerkingu",
    "Couldn't send mail to following users: %s " : "Gat ekki sent póst á eftirfarandi notendur: %s",
    "Preparing update" : "Undirbý uppfærslu",
    "Repair warning: " : "Viðvörun vegna viðgerðar: ",
    "Repair error: " : "Villa í viðgerð:",
    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
    "Updating database schema" : "Uppfæri gagnagrunnsskema",
    "Updated database" : "Uppfærði gagnagrunn",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Checked database schema update" : "Athugaði uppfærslu á gagnagrunnsskema.",
    "Checking updates of apps" : "Athuga með uppfærslur á öppum",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Checked database schema update for apps" : "Athugaði uppfærslu á gagnagrunnsskema fyrir öpp",
    "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
    "Set log level to debug" : "Setja annálsstig á aflúsun",
    "Reset log level" : "Frumstilla annálsstig",
    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
    "%s (3rdparty)" : "%s (frá 3. aðila)",
    "%s (incompatible)" : "%s (ósamhæft)",
    "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
    "Already up to date" : "Allt uppfært nú þegar",
    "Sunday" : "Sunnudagur",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Sun." : "Sun.",
    "Mon." : "Mán.",
    "Tue." : "Þri.",
    "Wed." : "Mið.",
    "Thu." : "Fim.",
    "Fri." : "Fös.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Má",
    "Tu" : "Þr",
    "We" : "Mi",
    "Th" : "Fi",
    "Fr" : "Fö",
    "Sa" : "La",
    "January" : "Janúar",
    "February" : "Febrúar",
    "March" : "Mars",
    "April" : "Apríl",
    "May" : "Maí",
    "June" : "Júní",
    "July" : "Júlí",
    "August" : "Ágúst",
    "September" : "September",
    "October" : "Október",
    "November" : "Nóvember",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maí.",
    "Jun." : "Jún.",
    "Jul." : "Júl.",
    "Aug." : "Ágú.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nóv.",
    "Dec." : "Des.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
    "Settings" : "Stillingar",
    "Saving..." : "Er að vista ...",
    "Dismiss" : "Hafna",
    "seconds ago" : "sekúndum síðan",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Ef þú hefur ekki virkjað endurheimtingarlykilinn, þá verður engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
    "I know what I'm doing" : "Ég veit hvað ég er að gera",
    "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
    "No" : "Nei",
    "Yes" : "Já",
    "Choose" : "Veldu",
    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
    "Ok" : "Í lagi",
    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
    "read-only" : "skrifvarið",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
    "One file conflict" : "Einn árekstur skráa",
    "New Files" : "Nýjar skrár",
    "Already existing files" : "Skrá er nú þegar til",
    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
    "Cancel" : "Hætta við",
    "Continue" : "Halda áfram",
    "(all selected)" : "(allt valið)",
    "({count} selected)" : "({count} valið)",
    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Miðlungs lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Þessi þjónn er ekki með virka nettengingu. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" HTTP-haus er ekki stilltur til jafns við \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum</a> okkar.",
    "Shared" : "Deilt",
    "Shared with {recipients}" : "Deilt með {recipients}",
    "Error" : "Villa",
    "Error while sharing" : "Villa við deilingu",
    "Error while unsharing" : "Villa við að hætta deilingu",
    "Error setting expiration date" : "Villa við að setja gildistíma",
    "The public link will expire no later than {days} days after it is created" : "Almenningstengillinn rennur út eigi síðar en {days} dögum eftir að hann er útbúinn",
    "Set expiration date" : "Setja gildistíma",
    "Expiration" : "Rennur út",
    "Expiration date" : "Gildir til",
    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
    "Share link" : "Deila tengli",
    "Link" : "Tengill",
    "Password protect" : "Verja með lykilorði",
    "Password" : "Lykilorð",
    "Allow editing" : "Leyfa breytingar",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "Sending ..." : "Sendi ...",
    "Email sent" : "Tölvupóstur sendur",
    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
    "Shared with you by {owner}" : "Deilt með þér af {owner}",
    "group" : "hópur",
    "remote" : "fjartengt",
    "notify by email" : "tilkynna með tölvupósti",
    "Unshare" : "Hætta deilingu",
    "can share" : "getur deilt",
    "can edit" : "getur breytt",
    "create" : "mynda",
    "change" : "breyta",
    "delete" : "eyða",
    "access control" : "aðgangsstýring",
    "Could not unshare" : "Gat ekki hætt deilingu",
    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
    "No users found for {search}" : "Engir notendur fundust með {search}",
    "{sharee} (group)" : "{sharee} (hópur)",
    "{sharee} (at {server})" : "{sharee} (á {server})",
    "{sharee} (remote)" : "{sharee} (fjartengdur)",
    "Share" : "Deila",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Deila með fólki í öðrum ownCloud-skýjum með skipuninni notandanafn@dæmi.is/owncloud",
    "Share with users…" : "Deila með notendum...",
    "Share with users, groups or remote users…" : "Deila með notendum, hópa eða fjartengdum notendum...",
    "Share with users or groups…" : "Deila með notendum eða hópum...",
    "Share with users or remote users…" : "Deila með notendum, hópa eða fjartengdum notendum...",
    "Error removing share" : "Villa við að fjarlægja sameign",
    "Warning" : "Aðvörun",
    "Error while sending notification" : "Villa við að senda tilkynningu",
    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
    "invisible" : "ósýnilegt",
    "({scope})" : "({scope})",
    "Delete" : "Eyða",
    "Rename" : "Endurnefna",
    "Collaborative tags" : "Samstarfsmerkingar",
    "The object type is not specified." : "Tegund hlutar ekki tilgreind",
    "Enter new" : "Sláðu inn nýtt",
    "Add" : "Bæta við",
    "Edit tags" : "Breyta merkjum",
    "Error loading dialog template: {error}" : "Villa við að hlaða valmynd sniðmátið: {error}",
    "No tags selected for deletion." : "Engin merki valin til að eyða.",
    "unknown text" : "óþekktur texti",
    "Hello world!" : "Halló heimur!",
    "sunny" : "sólríkt",
    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
    "Hello {name}" : "Halló {name}",
    "new" : "nýtt",
    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
    "An error occurred." : "Villa átti sér stað.",
    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
    "The update was successful. There were warnings." : "Uppfærslan tókst. Það voru viðvaranir.",
    "The update was successful. Redirecting you to ownCloud now." : "Uppfærslan heppnaðist. Beini þér til ownCloud nú.",
    "Searching other places" : "Leitað á öðrum stöðum",
    "No search results in other folders" : "Engar leitarniðurstöður í öðrum möppum",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} leitarniðurstöður í annarri möppu","{count} leitarniðurstöður í öðrum möppum"],
    "Personal" : "Einka",
    "Users" : "Notendur",
    "Apps" : "Forrit",
    "Admin" : "Stjórnun",
    "Help" : "Hjálp",
    "Access forbidden" : "Aðgangur bannaður",
    "File not found" : "Skrá finnst ekki",
    "The specified document has not been found on the server." : "Tiltekið skjal hefur ekki fundist á þjóninum.",
    "You can click here to return to %s." : "Þú getur smellt hér til að fara aftur á %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Sælir,\n\nbara láta þig vita að %s deildi %s með þér.\n\nSkoðaðu það: %s\n\n",
    "The share will expire on %s." : "Gildistími sameignar rennur út %s.",
    "Cheers!" : "Skál!",
    "Internal Server Error" : "Innri villa",
    "The server encountered an internal error and was unable to complete your request." : "Innri villa kom upp á þjóninum og ekki náðist að afgreiða beiðnina.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Hafðu samband við kerfisstjóra ef þessi villa birtist oft aftur, láttu þá tæknilegu upplýsingarnar hér að neðan fylgja með.",
    "More details can be found in the server log." : "Nánari upplýsingar er að finna í atburðaskrá (annál) þjónsins.",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s",
    "Type: %s" : "Tegund: %s",
    "Code: %s" : "Kóði: %s",
    "Message: %s" : "Skilaboð: %s",
    "File: %s" : "Skrá: %s",
    "Line: %s" : "Lína: %s",
    "Trace" : "Rekja",
    "Security warning" : "Öryggisviðvörun",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
    "Create an <strong>admin account</strong>" : "Útbúa <strong>kerfisstjóraaðgang</strong>",
    "Username" : "Notandanafn",
    "Storage & database" : "Geymsla & gagnagrunnur",
    "Data folder" : "Gagnamappa",
    "Configure the database" : "Stilla gagnagrunninn",
    "Only %s is available." : "Aðeins %s eru laus.",
    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
    "Database user" : "Notandi gagnagrunns",
    "Database password" : "Lykilorð gagnagrunns",
    "Database name" : "Heiti gagnagrunns",
    "Database tablespace" : "Töflusvæði gagnagrunns",
    "Database host" : "Netþjónn gagnagrunns",
    "Performance warning" : "Afkastaviðvörun",
    "SQLite will be used as database." : "SQLite verður notað sem gagnagrunnur.",
    "For larger installations we recommend to choose a different database backend." : "Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sérstaklega þegar verið er að nota skjáborðsforritið til að samræma skrár, þá er ekki mælt með notkun SQLite.",
    "Finish setup" : "Ljúka uppsetningu",
    "Finishing …" : "Að klára ...",
    "Need help?" : "Þarftu hjálp?",
    "See the documentation" : "Sjá hjálparskjölin",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hæ þú,<br><br>bara að láta þig vita að %s deildi <strong>%s</strong> með þér.<br><a href=\"%s\">Skoðaðu það!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
    "Log out" : "Skrá út",
    "Search" : "Leita",
    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
    "Log in" : "Skrá inn",
    "Wrong password. Reset it?" : "Rangt lykilorð. Endursetja?",
    "Wrong password." : "Rangt lykilorð.",
    "Stay logged in" : "Haldast skráður inn",
    "Alternative Logins" : "Aðrar innskráningar",
    "Use the following link to reset your password: {link}" : "Notað eftirfarandi veftengil til að endursetja lykilorðið þitt: {link}",
    "New password" : "Nýtt lykilorð",
    "New Password" : "Nýtt lykilorð",
    "Reset password" : "Endursetja lykilorð",
    "This ownCloud instance is currently in single user mode." : "Þetta ownCloud eintak er nú í eins-notanda ham.",
    "This means only administrators can use the instance." : "Þetta þýðir aðeins stjórnendur geta notað eintakið.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
    "Thank you for your patience." : "Þakka þér fyrir biðlundina.",
    "You are accessing the server from an untrusted domain." : "Þú ert að tengjast þjóninum frá ótreystu léni.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi á þessu tilviki, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Það fer eftir stillingum þínum, sem stjórnandi þá gætir þú einnig notað hnappinn hér fyrir neðan til að treysta þessu léni.",
    "Add \"%s\" as trusted domain" : "Bæta við \"%s\" sem treystu léni",
    "App update required" : "App þarfnast uppfærslu ",
    "%s will be updated to version %s" : "%s verður uppfært í útgáfu %s.",
    "These apps will be updated:" : "Eftirfarandi öpp verða uppfærð:",
    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
    "Start update" : "Hefja uppfærslu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
    "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
